@@ -122,4 +122,17 @@ def model_log_reg():
     return model
 def vec_text():
     vectorizer = joblib.load('tfidf_vectorizer.pkl')
-    return vectorizer
\ No newline at end of file
+    return vectorizer
+def predect_sentiment(text):
+    model = model_log_reg()
+    vectorizer = vec_text()
+    X_test = vectorizer.transform(text)
+    predictions = model.predict(X_test)
+    sentiment = 'Positive' if predictions == 1 else 'Negative'
+    return sentiment
+def comment_dataFrame_model(UrlProduct):
+    reviews = extract_all_reviews(UrlProduct)
+    reviews_cleaned = [clean_comment(review.replace("\n", " ")) for review in reviews]
+    df = pd.DataFrame(reviews_cleaned, columns=['comment'])
+    df['sentiment'] = df['comment'].apply(predect_sentiment)
+    return df
\ No newline at end of file
